==> SkyHanni-4.26.0-mc1.21.10-sources.jar: at/hannibal2/skyhanni/test/HighlightMissingRepoItems.kt <==
package at.hannibal2.skyhanni.test

import at.hannibal2.skyhanni.SkyHanniMod
import at.hannibal2.skyhanni.api.event.HandleEvent
import at.hannibal2.skyhanni.config.ConfigUpdaterMigrator
import at.hannibal2.skyhanni.events.GuiContainerEvent
import at.hannibal2.skyhanni.skyhannimodule.SkyHanniModule
import at.hannibal2.skyhanni.utils.InventoryUtils
import at.hannibal2.skyhanni.utils.ItemUtils.getInternalNameOrNull
import at.hannibal2.skyhanni.utils.LorenzColor
import at.hannibal2.skyhanni.utils.NeuItems
import at.hannibal2.skyhanni.utils.RenderUtils.highlight
import net.minecraft.client.gui.screen.ingame.GenericContainerScreen
import net.minecraft.client.gui.screen.ingame.InventoryScreen
import net.minecraft.screen.slot.Slot

@SkyHanniModule
object HighlightMissingRepoItems {

    @HandleEvent(priority = HandleEvent.LOWEST, onlyOnSkyblock = true)
    fun onBackgroundDrawn(event: GuiContainerEvent.BackgroundDrawnEvent) {
        if (!SkyHanniMod.feature.dev.debug.highlightMissingRepo) return

        val gui = event.gui

        if (gui is GenericContainerScreen) {
            highlightItems(event.container.slots)
        } else if (gui is InventoryScreen) {
            highlightItems(InventoryUtils.getSlotsInOwnInventory())
        }
    }

    private fun highlightItems(slots: Iterable<Slot>) {
        if (NeuItems.allInternalNames.isEmpty()) return
        for (slot in slots) {
            val internalName = slot.stack?.getInternalNameOrNull() ?: continue
            val asString = internalName.asString()
            if (asString.startsWith("BUILDER_")) continue // Skip builder items as we filter them out of allInternalNames

            if (NeuItems.ignoreItemsFilter.match(asString)) continue
            if (NeuItems.allInternalNames[asString] != null) continue

            slot.highlight(LorenzColor.RED)
        }
    }

    @HandleEvent
    fun onConfigFix(event: ConfigUpdaterMigrator.ConfigFixEvent) {
        event.move(3, "dev.highlightMissingRepo", "dev.debug.highlightMissingRepo")
    }
}

==> SkyHanni-5.4.0-mc1.8.9-sources.jar: at/hannibal2/skyhanni/test/HighlightMissingRepoItems.kt <==
package at.hannibal2.skyhanni.test

import at.hannibal2.skyhanni.SkyHanniMod
import at.hannibal2.skyhanni.api.event.HandleEvent
import at.hannibal2.skyhanni.config.ConfigUpdaterMigrator
import at.hannibal2.skyhanni.events.GuiContainerEvent
import at.hannibal2.skyhanni.skyhannimodule.SkyHanniModule
import at.hannibal2.skyhanni.utils.InventoryUtils
import at.hannibal2.skyhanni.utils.ItemUtils.getInternalNameOrNull
import at.hannibal2.skyhanni.utils.LorenzColor
import at.hannibal2.skyhanni.utils.NeuItems
import at.hannibal2.skyhanni.utils.RenderUtils.highlight
import net.minecraft.client.gui.inventory.GuiChest
import net.minecraft.client.gui.inventory.GuiInventory
import net.minecraft.inventory.Slot

@SkyHanniModule
object HighlightMissingRepoItems {

    @HandleEvent(priority = HandleEvent.LOWEST, onlyOnSkyblock = true)
    fun onBackgroundDrawn(event: GuiContainerEvent.BackgroundDrawnEvent) {
        if (!SkyHanniMod.feature.dev.debug.highlightMissingRepo) return

        val gui = event.gui

        if (gui is GuiChest) {
            highlightItems(event.container.inventorySlots)
        } else if (gui is GuiInventory) {
            highlightItems(InventoryUtils.getSlotsInOwnInventory())
        }
    }

    private fun highlightItems(slots: Iterable<Slot>) {
        if (NeuItems.allInternalNames.isEmpty()) return
        for (slot in slots) {
            val internalName = slot.stack?.getInternalNameOrNull() ?: continue
            val asString = internalName.asString()
            if (asString.startsWith("BUILDER_")) continue // Skip builder items as we filter them out of allInternalNames

            if (NeuItems.ignoreItemsFilter.match(asString)) continue
            if (NeuItems.allInternalNames[asString] != null) continue

            slot.highlight(LorenzColor.RED)
        }
    }

    @HandleEvent
    fun onConfigFix(event: ConfigUpdaterMigrator.ConfigFixEvent) {
        event.move(3, "dev.highlightMissingRepo", "dev.debug.highlightMissingRepo")
    }
}
